==> hinemos_src-2.4.0.tar.gz: Hinemos_src-2.4.0/SyslogNG/src/com/clustercontrol/syslogng/etc/action/LogListAction.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.syslogng.etc.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.syslogng.action.LogManager;
import com.clustercontrol.syslogng.dialog.LogListDialog;
import com.clustercontrol.util.Messages;

/**
 * syslog-ng[一覧]ダイアログを表示するクライアント側アクションクラス<BR>
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class LogListAction implements IWorkbenchWindowActionDelegate {
	
	/**
	 * 終了する際に呼ばれます。
	 * 
	 * @see org.eclipse.ui.IWorkbenchWindowActionDelegate#dispose()
	 */
	public void dispose() {
	}
	
	/**
	 * ワークベンチにロードされた際に呼ばれます。
	 * 
	 * @see org.eclipse.ui.IWorkbenchWindowActionDelegate#init(org.eclipse.ui.IWorkbenchWindow)
	 */
	public void init(IWorkbenchWindow window) {
	}
	
	/**
	 * syslog-ng[一覧]ダイアログを表示します。
	 * 
	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
	 * @see com.clustercontrol.syslogng.dialog.LogListDialog
	 */
	public void run(IAction action) {
		// シェルを取得
		Shell shell = PlatformUI.getWorkbench().getActiveWorkbenchWindow()
		.getShell();
		
		// ダイアログ表示及び終了処理
		LogListDialog dialog = new LogListDialog(shell);
		
		if (dialog.open() == IDialogConstants.OK_ID) {
			if (LogManager.getInstance().commit()){
				MessageDialog.openInformation(
						null,
						Messages.getString("message"),
						Messages.getString("message.monitor.54"));
			}
		}
	}
	
	/**
	 * 選択を変更した際に呼ばれます。
	 * 
	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
	 *      org.eclipse.jface.viewers.ISelection)
	 */
	public void selectionChanged(IAction action, ISelection selection) {
	}
}

==> hinemos_src-3.0.4.tar.gz: Hinemos_src-3.0.4/SyslogNG/src/com/clustercontrol/syslogng/etc/action/LogListAction.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.syslogng.etc.action;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.naming.NamingException;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.syslogng.action.LogManager;
import com.clustercontrol.syslogng.dialog.LogListDialog;
import com.clustercontrol.util.Messages;

/**
 * syslog-ng[一覧]ダイアログを表示するクライアント側アクションクラス<BR>
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class LogListAction implements IWorkbenchWindowActionDelegate {
	
	/**
	 * 終了する際に呼ばれます。
	 * 
	 * @see org.eclipse.ui.IWorkbenchWindowActionDelegate#dispose()
	 */
	public void dispose() {
	}
	
	/**
	 * ワークベンチにロードされた際に呼ばれます。
	 * 
	 * @see org.eclipse.ui.IWorkbenchWindowActionDelegate#init(org.eclipse.ui.IWorkbenchWindow)
	 */
	public void init(IWorkbenchWindow window) {
	}
	
	/**
	 * syslog-ng[一覧]ダイアログを表示します。
	 * 
	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
	 * @see com.clustercontrol.syslogng.dialog.LogListDialog
	 */
	public void run(IAction action) {
		// シェルを取得
		Shell shell = PlatformUI.getWorkbench().getActiveWorkbenchWindow()
		.getShell();
		
		// ダイアログ表示及び終了処理
		LogListDialog dialog = new LogListDialog(shell);
		
		if (dialog.open() == IDialogConstants.OK_ID) {
			try {
				if (LogManager.getInstance().commit()){
					MessageDialog.openInformation(
							null,
							Messages.getString("message"),
							Messages.getString("message.monitor.54"));
				}
			} catch (CreateException e) {
            	MessageDialog.openError(
            			null, 
            			Messages.getString("failed"), 
            			Messages.getString("message.monitor.56"));
			} catch (RemoveException e) {
				MessageDialog.openError(
            			null, 
            			Messages.getString("failed"), 
            			Messages.getString("message.monitor.56"));
			} catch (FinderException e) {
				MessageDialog.openError(
            			null, 
            			Messages.getString("failed"), 
            			Messages.getString("message.monitor.56"));
			} catch (NamingException e) {
				MessageDialog.openError(
            			null, 
            			Messages.getString("failed"), 
            			Messages.getString("message.monitor.56"));
			}
		}
	}
	
	/**
	 * 選択を変更した際に呼ばれます。
	 * 
	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
	 *      org.eclipse.jface.viewers.ISelection)
	 */
	public void selectionChanged(IAction action, ISelection selection) {
	}
}
